@@ -11,10 +11,8 @@
 #ifdef LIBXML_LZMA_ENABLED
 
 #include <string.h>
-#ifdef HAVE_ERRNO_H
+#include <stdlib.h>
 #include <errno.h>
-#endif
-
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -28,9 +26,6 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h>
-#endif
 #ifdef LIBXML_ZLIB_ENABLED
 #include <zlib.h>
 #endif
@@ -389,6 +384,10 @@ xz_head(xz_statep state)
     int flags;
     unsigned len;
 
+    /* Avoid unused variable warning if features are disabled. */
+    (void) flags;
+    (void) len;
+
     /* allocate read buffers and inflate memory */
     if (state->size == 0) {
         /* allocate buffers */
@@ -536,6 +535,10 @@ xz_decomp(xz_statep state)
 
     lzma_action action = LZMA_RUN;
 
+    /* Avoid unused variable warning if features are disabled. */
+    (void) crc;
+    (void) len;
+
     /* fill output buffer up to end of deflate stream */
     had = strm->avail_out;
     do {
